@@ -1015,9 +1015,4 @@ int htp_connp_req_data(htp_connp_t *connp, const htp_time_t *timestamp, const vo
             return HTP_STREAM_ERROR;
         }
     }
-
-    // Permanent stream error.
-    connp->in_status = HTP_STREAM_ERROR;
-
-    return HTP_STREAM_ERROR;
 }
